Response

Enum Response 

pub enum Response {
    Values(Vec<Value>),
    Stored,
    NotStored,
    Deleted,
    NotFound,
    Exists,
    Ok,
    Numeric(u64),
    Version(Vec<u8>),
    Error,
    ClientError(Vec<u8>),
    ServerError(Vec<u8>),
}
A parsed Memcache response.

Variants



Values(Vec<Value>)

Value response from GET (may contain multiple values for multi-get)



Stored

STORED response from SET



NotStored

NOT_STORED response from SET



Deleted

DELETED response from DELETE



NotFound

NOT_FOUND response from DELETE



Exists

EXISTS response from CAS



Ok

OK response (from flush_all, touch, etc.)



Numeric(u64)

Numeric response from INCR/DECR (the new value after the operation).



Version(Vec<u8>)

VERSION response



Error

Generic error



ClientError(Vec<u8>)

Client error with message



ServerError(Vec<u8>)

Server error with message

Implementations

Source

impl Response

pub fn stored() -> Self

Create a STORED response.

pub fn not_stored() -> Self

Create a NOT_STORED response.

pub fn deleted() -> Self

Create a DELETED response.

pub fn not_found() -> Self

Create a NOT_FOUND response.

pub fn ok() -> Self

Create an OK response.

pub fn numeric(value: u64) -> Self

Create a numeric response (from INCR/DECR).

pub fn miss() -> Self

Create an empty VALUES response (cache miss).

pub fn hit(key: &[u8], flags: u32, data: &[u8]) -> Self

Create a VALUES response with a single value (cache hit).

pub fn error() -> Self

Create an ERROR response.

pub fn client_error(msg: &[u8]) -> Self

Create a CLIENT_ERROR response.

pub fn server_error(msg: &[u8]) -> Self

Create a SERVER_ERROR response.

pub fn is_error(&self) -> bool

Returns true if this is an error response.

pub fn is_miss(&self) -> bool

Returns true if this represents a cache miss.

pub fn is_stored(&self) -> bool

Returns true if this is a successful storage response.

pub fn parse(data: &[u8]) -> Result<(Self, usize), ParseError>

Parse a response from a byte buffer.

Returns the parsed response and the number of bytes consumed.

pub fn encode(&self, buf: &mut [u8]) -> usize

Encode this response into a buffer.

Returns the number of bytes written.

pub fn encode_stored(buf: &mut [u8]) -> usize

Encode STORED directly to buffer.

pub fn encode_not_stored(buf: &mut [u8]) -> usize

Encode NOT_STORED directly to buffer.

pub fn encode_deleted(buf: &mut [u8]) -> usize

Encode DELETED directly to buffer.

pub fn encode_not_found(buf: &mut [u8]) -> usize

Encode NOT_FOUND directly to buffer.

pub fn encode_end(buf: &mut [u8]) -> usize

Encode END (empty get response) directly to buffer.

pub fn encode_value( buf: &mut [u8], key: &[u8], flags: u32, data: &[u8], ) -> usize

Encode a single VALUE response directly to buffer.

pub fn encode_value_with_cas( buf: &mut [u8], key: &[u8], flags: u32, data: &[u8], cas: u64, ) -> usize

Encode a single VALUE response with CAS token directly to buffer (GETS response).

Format: VALUE <key> <flags> <bytes> <cas>\r\n<data>\r\nEND\r\n

pub fn encode_exists(buf: &mut [u8]) -> usize

Encode EXISTS response directly to buffer.

pub fn encode_numeric(buf: &mut [u8], value: u64) -> usize

Encode a numeric response directly to buffer (INCR/DECR result).

pub fn encode_server_error(buf: &mut [u8], msg: &[u8]) -> usize

Encode a SERVER_ERROR response directly to buffer.